
# Slot: term

The ECO term representing the type of evidence

URI: [gocam:evidenceItem__term](https://w3id.org/gocam/evidenceItem__term)


## Domain and Range

None &#8594;  <sub>0..1</sub> [EvidenceTermObject](EvidenceTermObject.md)

## Parents


## Children


## Used by

 * [EvidenceItem](EvidenceItem.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Examples:** | | Example({
  'value': 'ECO:0000314',
  'description': 'direct assay evidence used in manual assertion (IDA)'
}) |
